ParamTake

Trait ParamTake 

pub trait ParamTake<T> {
    type Transformed;

    // Required method
    fn param_take(self) -> (Self::Transformed, T);
}
Item of type T has been set in certain_map slot and can be removed from the slot, leaving it vacant.

Required Associated Types

Required Methods

fn param_take(self) -> (Self::Transformed, T)

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors